"""API"""
from sgqlc.endpoint.http import HTTPEndpoint
from sgqlc.operation import Operation

from deepcrawl_graphql.deepcrawl_schema import deepcrawl_schema

ENDPOINT = "https://graph.deepcrawl.com/"


class DeepCrawlConnection:
    """DeepCrawlConnection"""

    def __init__(self, user_key_id=None, secret=None, token=None) -> None:
        self.token = token

        if not token:
            assert user_key_id and secret, "Missing user_key_id and secret"
            self.token = self._get_token(user_key_id, secret)

        self.endpoint = HTTPEndpoint(ENDPOINT, self._headers)

    @property
    def _headers(self) -> dict:
        """Return authentication header"""
        return {"x-auth-token": self.token}

    def _get_token(self, user_key_id, secret) -> str:
        """Requests for a token using the user_key_id and secret"""
        mutation = Operation(deepcrawl_schema.Mutation)
        mutation.create_session_using_user_key(input={"user_key_id": user_key_id, "secret": secret})

        endpoint = HTTPEndpoint(ENDPOINT)
        data = endpoint(mutation)
        obj = mutation + data

        return obj.create_session_using_user_key.token

    def get_version(self) -> str:
        """Return endpoint version"""
        query = Operation(deepcrawl_schema.Query)
        query.version()

        data = self.endpoint(query)
        obj = query + data
        return obj.version

    def run_query(self, query: Operation):
        """Run query"""
        data = self.endpoint(query)
        obj = query + data
        return obj
